@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2010 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -148,13 +148,14 @@ sebie_update_view(struct sebie_s *sebie)
 
 
 void
-sebie_error_popup(struct sebie_s *sebie, gchar *error_str)
+sebie_error_popup(struct sebie_s *sebie, const gchar *error_str)
 {
   GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW(sebie->view.window1),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_MESSAGE_ERROR,
 					      GTK_BUTTONS_CLOSE,
-					      error_str);
+                          "%s",
+                          error_str);
 #if 1
   // modal dialog: you must click to resume
   gtk_dialog_run (GTK_DIALOG (dialog));
@@ -180,7 +181,7 @@ sebie_file_list_clear(struct sebie_s *sebie)
 
 
 void
-sebie_file_list_add(struct sebie_s *sebie, G_CONST_RETURN gchar *filename)
+sebie_file_list_add(struct sebie_s *sebie, const gchar *filename)
 {
   if (sebie->model.file_list == NULL) {
     sebie->model.file_list = gtk_list_store_new(1, G_TYPE_STRING);
@@ -267,7 +268,7 @@ sebie_update_file_list(struct sebie_s *sebie)
     return;
   }
 
-  G_CONST_RETURN gchar *next;
+  const gchar *next;
   while((next = g_dir_read_name(gdir)) != NULL) {
     sebie_debug("next %s\n", next);
 
@@ -335,20 +336,22 @@ save_sebie_config(struct sebie_s *sebie)
 {
   if (sebie->model_tags) {
     sebie_config_spec config_spec[] = {
-      { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "" },
-      { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
-      { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
-      { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
-      { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
-      { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
-      { "ImageGrayscale", CONFIG_INTEGER, &sebie->model.image_grayscale, 0},
-      { "Window1Width", CONFIG_INTEGER, &sebie->model.window1_width, 1187},
-      { "Window1Height", CONFIG_INTEGER, &sebie->model.window1_height, 832},
-      { "PixbufWidth",  CONFIG_INTEGER, &sebie->model.pixbuf_width, 1024},
-      { "PixbufHeight", CONFIG_INTEGER, &sebie->model.pixbuf_height, 768},
-      { NULL, CONFIG_END, NULL, 0}
+      { .name = "InputPath", .type = CONFIG_STRING, .storage.string = &sebie->model.input_path, .defvalue.string = "" },
+      { .name = "InputRegEx", .type = CONFIG_STRING, .storage.string = &sebie->model.input_regex, .defvalue.string = "\\([0-9]*\\).jpg" },
+      { .name = "OutputFormat", .type = CONFIG_STRING, .storage.string = &sebie->model.output_format, .defvalue.string = "Image%s.jpg" },
+      { .name = "ImageOutputWidth", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.selection_fac_width, .defvalue.integer = 1024},
+      { .name = "ImageOutputHeight", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.selection_fac_height, .defvalue.integer = 768},
+      { .name = "ImageGamma", .type = CONFIG_DOUBLE, .storage.doublev = &sebie->model.image_gamma, .defvalue.doublev = 1.0},
+      { .name = "ImageGrayscale", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.image_grayscale, .defvalue.integer = 0},
+      { .name = "Window1Width", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.window1_width, .defvalue.integer = 1187},
+      { .name = "Window1Height", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.window1_height, .defvalue.integer = 832},
+      { .name = "PixbufWidth", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.pixbuf_width, .defvalue.integer = 1024},
+      { .name = "PixbufHeight", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.pixbuf_height, .defvalue.integer = 768},
+      { .name = NULL, .type = CONFIG_END, .storage.string = NULL, .defvalue.string = NULL}
     };
+
     sebie_write_config(sebie->config_file, config_spec);
+
     sebie->model_tags = 0;
   }
 }
@@ -368,20 +371,20 @@ init_sebie_model(struct sebie_s *sebie)
   }
   
   sebie_config_spec config_spec[] = {
-    { "InputPath",  CONFIG_STRING, &sebie->model.input_path, "." },
-    { "InputRegEx", CONFIG_STRING, &sebie->model.input_regex, "\\([0-9]*\\).jpg" },
-    { "OutputFormat", CONFIG_STRING, &sebie->model.output_format, "Image%s.jpg" },
-    { "ImageOutputWidth",  CONFIG_INTEGER, &sebie->model.selection_fac_width, 1024},
-    { "ImageOutputHeight", CONFIG_INTEGER, &sebie->model.selection_fac_height, 768},
-    { "ImageGamma", CONFIG_DOUBLE, &sebie->model.image_gamma, 1.0},
-    { "ImageGrayscale", CONFIG_INTEGER, &sebie->model.image_grayscale, 0},
-    { "Window1Width", CONFIG_INTEGER, &sebie->model.window1_width, 1187},
-    { "Window1Height", CONFIG_INTEGER, &sebie->model.window1_height, 832},
-    { "PixbufWidth",  CONFIG_INTEGER, &sebie->model.pixbuf_width, 1024},
-    { "PixbufHeight", CONFIG_INTEGER, &sebie->model.pixbuf_height, 768},
-    { NULL, CONFIG_END, NULL, 0}
+    { .name = "InputPath", .type = CONFIG_STRING, .storage.string = &sebie->model.input_path, .defvalue.string = "" },
+    { .name = "InputRegEx", .type = CONFIG_STRING, .storage.string = &sebie->model.input_regex, .defvalue.string = "\\([0-9]*\\).jpg" },
+    { .name = "OutputFormat", .type = CONFIG_STRING, .storage.string = &sebie->model.output_format, .defvalue.string = "Image%s.jpg" },
+    { .name = "ImageOutputWidth", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.selection_fac_width, .defvalue.integer = 1024},
+    { .name = "ImageOutputHeight", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.selection_fac_height, .defvalue.integer = 768},
+    { .name = "ImageGamma", .type = CONFIG_DOUBLE, .storage.doublev = &sebie->model.image_gamma, .defvalue.doublev = 1.0},
+    { .name = "ImageGrayscale", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.image_grayscale, .defvalue.integer = 0},
+    { .name = "Window1Width", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.window1_width, .defvalue.integer = 1187},
+    { .name = "Window1Height", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.window1_height, .defvalue.integer = 832},
+    { .name = "PixbufWidth", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.pixbuf_width, .defvalue.integer = 1024},
+    { .name = "PixbufHeight", .type = CONFIG_INTEGER, .storage.integer = &sebie->model.pixbuf_height, .defvalue.integer = 768},
+    { .name = NULL, .type = CONFIG_END, .storage.string = NULL, .defvalue.string = NULL}
   };
-  
+
   sebie_read_config(sebie->config_file, config_spec);
 
   sebie->model.input_file_path = NULL;
