@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2010 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -69,7 +69,7 @@ on_entry_input_path_changed (GtkEditable *editable,
 			     gpointer    user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
-  G_CONST_RETURN gchar *input_path = gtk_entry_get_text(GTK_ENTRY(editable));
+  const gchar *input_path = gtk_entry_get_text(GTK_ENTRY(editable));
   sebie_set_string(&sebie->model.input_path, input_path);
   sebie->model_tags |= SEBIE_MODEL_INPUT_PATH;
   sebie_update_file_list(sebie);
@@ -81,7 +81,7 @@ on_entry_input_regex_changed (GtkEditable *editable,
 			     gpointer    user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
-  G_CONST_RETURN gchar *input_regex = gtk_entry_get_text(GTK_ENTRY(editable));
+  const gchar *input_regex = gtk_entry_get_text(GTK_ENTRY(editable));
   sebie_debug("input_regex = %s\n", input_regex);
   sebie_set_string(&sebie->model.input_regex, input_regex);
   sebie->model_tags |= SEBIE_MODEL_INPUT_REGEX;
@@ -94,7 +94,7 @@ on_entry_output_format_changed (GtkEditable *editable,
 				gpointer    user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
-  G_CONST_RETURN gchar *output_format = gtk_entry_get_text(GTK_ENTRY(editable));
+  const gchar *output_format = gtk_entry_get_text(GTK_ENTRY(editable));
   sebie_debug("output_format = %s\n", output_format);
   sebie_set_string(&sebie->model.output_format, output_format);
   sebie->model_tags |= SEBIE_MODEL_OUTPUT_FORMAT;
@@ -136,7 +136,7 @@ drawingarea1_size_allocate (GtkWidget *widget,
 		allocation->width,
 		allocation->height);
  
-    gtk_window_get_size(sebie->view.window1, &window1_width, &window1_height);
+    gtk_window_get_size(GTK_WINDOW(sebie->view.window1), &window1_width, &window1_height);
     sebie->model.window1_width = window1_width;
     sebie->model.window1_height = window1_height;
     sebie->model.pixbuf_width = allocation->width;
@@ -289,7 +289,7 @@ on_entry_selection_fac_width_changed (GtkEditable *editable,
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
   if (sebie->dirty_tags == 0) {
-    G_CONST_RETURN gchar *fac_width = gtk_entry_get_text(GTK_ENTRY(editable));
+    const gchar *fac_width = gtk_entry_get_text(GTK_ENTRY(editable));
     sebie_debug("fac_width = %s %d\n", fac_width, atoi(fac_width));
     sebie->model.selection_fac_width = atoi(fac_width);
     sebie->model_tags |= SEBIE_MODEL_UPDATE_SELECTION_FAC;
@@ -304,7 +304,7 @@ on_entry_selection_fac_height_changed (GtkEditable *editable,
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
   if (sebie->dirty_tags == 0) {
-    G_CONST_RETURN gchar *fac_height = gtk_entry_get_text(GTK_ENTRY(editable));
+    const gchar *fac_height = gtk_entry_get_text(GTK_ENTRY(editable));
     sebie_debug("fac_height = %s %d\n", fac_height, atoi(fac_height));
     sebie->model.selection_fac_height = atoi(fac_height);
     sebie->model_tags |= SEBIE_MODEL_UPDATE_SELECTION_FAC;
@@ -333,7 +333,7 @@ on_entry_selection_gamma_changed (GtkEditable *editable,
 				  gpointer  user_data)
 {
   struct sebie_s *sebie = (struct sebie_s *)user_data;
-  G_CONST_RETURN gchar *gamma_str = gtk_entry_get_text(GTK_ENTRY(editable));
+  const gchar *gamma_str = gtk_entry_get_text(GTK_ENTRY(editable));
   sebie_debug("image_gamma_str = '%s'\n", gamma_str);
   double new_gamma = 0.0;
   if (sscanf(gamma_str, "%lf", &new_gamma) != 1) {
