@@ -1,5 +1,5 @@
 /**
- *  Copyright 2002-2010 Peter Seiderer <Peter.Seiderer@ciselant.de>
+ *  Copyright 2002-2022 Peter Seiderer <Peter.Seiderer@ciselant.de>
  *
  *  This file is part of SeBIE.
  *
@@ -255,7 +255,7 @@ init_sebie_view(struct sebie_s *sebie)
   gtk_widget_show (sebie->view.drawingarea1);
   gtk_paned_pack2 (GTK_PANED (sebie->view.hpaned1), sebie->view.drawingarea1, TRUE, TRUE);
 
-  gtk_window_set_default_size(sebie->view.window1,
+  gtk_window_set_default_size(GTK_WINDOW (sebie->view.window1),
 			      sebie->model.window1_width,
 			      sebie->model.window1_height);
 
